Consts — Django Building Blocks documentation

# Consts

Contents

- Consts

  - Field names

## Field names

Set of constants set to the name of common fields

param ID

  ‘id’

param UUID

  ‘uuid’

param SLUG

  ‘slug’

param CREATED

  ‘created’

param MODIFIED

  ‘modified’

param NAME

  ‘name’

param TITLE

  ‘title’

param DESCRIPTION

  ‘description’

param BODY

  ‘body’

param NOTES

  ‘notes’

param CATEGORY

  ‘category’

param TYPE

  ‘type’

param IMAGE

  ‘image’

param ICON

  ‘icon’

param STATUS

  ‘status’

param USER

  ‘user’

param OWNER

  ‘owner’

param AUTHOR

  ‘author’

param ADDRESS

  ‘address’

param EMAIL

  ‘email’

param PHONE

  ‘phone’

param LOCATION

  ‘location’

param PRICE

  ‘price’

param AMOUNT

  ‘amount’

param PRODUCT

  ‘product’

param QUANTITY

  ‘quantity’

param START

  ‘start’

param START_DT

  ‘start_dt’

param END

  ‘end’

param END_DT

  ‘end_dt’

param PUBLISHED_DT

  ‘published_dt’

param LINK_DISPLAY

  ‘link_display’